diff -urN asterisk/channels/h323.orig/ast_h323.cxx asterisk/channels/h323/ast_h323.cxx
--- asterisk/channels/h323.orig/ast_h323.cxx	2010-05-30 23:13:03.000000000 +0000
+++ asterisk/channels/h323/ast_h323.cxx	2010-05-30 23:25:06.000000000 +0000
@@ -1861,17 +1861,35 @@
 	return TRUE;
 }
 
+#ifdef NEED_RTP_QOS_PARAM
 H323Channel * MyH323Connection::CreateRealTimeLogicalChannel(const H323Capability & capability,
 									H323Channel::Directions dir,
 									unsigned sessionID,
 									const H245_H2250LogicalChannelParameters * /*param*/,
 									RTP_QOS * /*param*/ )
+#else
+H323Channel * MyH323Connection::CreateRealTimeLogicalChannel(const H323Capability & capability,
+									H323Channel::Directions dir,
+									unsigned sessionID,
+									const H245_H2250LogicalChannelParameters * /*param*/)
+#endif
 {
+	PIPSocket::Address externIpAddr;
+	WORD externPort
+
 	/* Do not open tx channel when transmitter has been paused by empty TCS */
 	if ((dir == H323Channel::IsTransmitter) && transmitterSidePaused)
 		return NULL;
 
-	return new MyH323_ExternalRTPChannel(*this, capability, dir, sessionID);
+	GetControlChannel().GetLocalAddress().GetIpAndPort(externIpAddr, externPort);
+	if (h323debug){
+		cout << "\t-- Create RealTime logical channel: " << endl;
+		cout << "\t\t-- SessionID: " << sessionID << endl;
+		cout << "\t\t-- ExternalIpAddress: " <<  externIpAddr << endl;
+		cout << "\t\t-- ExternalPort: " << externPort << endl;
+	}
+
+	return new MyH323_ExternalRTPChannel(*this, capability, dir, sessionID, externIpAddr, externPort);
 }
 
 /** This callback function is invoked once upon creation of each
@@ -2132,8 +2150,10 @@
 MyH323_ExternalRTPChannel::MyH323_ExternalRTPChannel(MyH323Connection & connection,
 							const H323Capability & capability,
 							Directions direction,
-							unsigned id)
-	: H323_ExternalRTPChannel::H323_ExternalRTPChannel(connection, capability, direction, id)
+							unsigned id,
+							const PIPSocket::Address & ip,
+							WORD dataPort)
+	: H323_ExternalRTPChannel::H323_ExternalRTPChannel(connection, capability, direction, id, ip, dataPort)
 {
 	struct rtp_info *info;
 
@@ -2143,7 +2163,7 @@
 		cout << "\tERROR: on_external_rtp_create failure" << endl;
 		return;
 	} else {
-		localIpAddr = info->addr;
+		localIpAddr = ip;
 		localPort = info->port;
 		/* tell the H.323 stack */
 		SetExternalAddress(H323TransportAddress(localIpAddr, localPort), H323TransportAddress(localIpAddr, localPort + 1));
@@ -2358,7 +2378,7 @@
 	H323ListenerTCP *tcpListener;
 	tcpListener = new H323ListenerTCP(*endPoint, interfaceAddress, (WORD)listenPort);
 	if (!endPoint->StartListener(tcpListener)) {
-		cout << "ERROR: Could not open H.323 listener port on " << ((H323ListenerTCP *) tcpListener)->GetListenerPort() << endl;
+		cout << "ERROR: Could not open H.323 listener on " << ((H323ListenerTCP *) tcpListener)->GetTransportAddress() << endl;
 		delete tcpListener;
 		return 1;
 	}
diff -urN asterisk/channels/h323.orig/ast_h323.h asterisk/channels/h323/ast_h323.h
--- asterisk/channels/h323.orig/ast_h323.h	2010-05-30 23:13:03.000000000 +0000
+++ asterisk/channels/h323/ast_h323.h	2010-05-30 23:23:48.000000000 +0000
@@ -33,6 +33,10 @@
 
 #define VERSION(a,b,c) ((a)*10000+(b)*100+(c))
 
+#if (VERSION(OPENH323_MAJOR, OPENH323_MINOR, OPENH323_BUILD) >= VERSION(1,13,4))
+#define NEED_RTP_QOS_PARAM 1
+#endif
+
 class MyH323EndPoint : public H323EndPoint
 {
 	PCLASSINFO(MyH323EndPoint, H323EndPoint);
@@ -62,11 +66,18 @@
 public:
 	MyH323Connection(MyH323EndPoint &, unsigned, unsigned);
 	~MyH323Connection();
+#ifdef NEED_RTP_QOS_PARA
 	H323Channel * CreateRealTimeLogicalChannel(const H323Capability &,
 			H323Channel::Directions,
 			unsigned,
 			const H245_H2250LogicalChannelParameters *,
 			RTP_QOS *);
+#else
+	H323Channel * CreateRealTimeLogicalChannel(const H323Capability &,
+			H323Channel::Directions,
+			unsigned,
+			const H245_H2250LogicalChannelParameters *);
+#endif
 	H323Connection::AnswerCallResponse OnAnswerCall(const PString &,
 			const H323SignalPDU &,
 			H323SignalPDU &);
@@ -138,7 +149,9 @@
 			MyH323Connection & connection,
 			const H323Capability & capability,
 			Directions direction,
-			unsigned sessionID);
+			unsigned sessionID,
+			const PIPSocket::Address & ip,
+			WORD dataPort);
 
 	~MyH323_ExternalRTPChannel();
 
